/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.2.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for M52223EVB evaluation board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS         (4u)
#define LED0_BIT         (0u)
#define LED1_BIT         (1u)
#define LED2_BIT         (2u)
#define LED3_BIT         (3u)
#define LEDPORT_STATE    (*(volatile unsigned char*)0x4010000Fu)
#define LEDPORT_DDR      (*(volatile unsigned char*)0x40100027u)
#define LEDPORT_DATA     (*(volatile unsigned char*)0x4010000Fu)
#define LED_ALL_MASK     ((1u << LED0_BIT) | (1u << LED1_BIT) | (1u << LED2_BIT) | (1u << LED3_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LEDPORT_DDR  |=  LED_ALL_MASK;  // Set data direction to output
  LEDPORT_DATA &= ~LED_ALL_MASK;  // Initially switch off LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    LEDPORT_DATA |= (1u << Index);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    LEDPORT_DATA &= ~(1u << Index);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < NUM_LEDS) {
    if (LEDPORT_DATA & (1u << Index)) {
      LEDPORT_DATA &= ~(1u << Index);
    } else {
      LEDPORT_DATA |= (1u << Index);
    }
  }
}

/*************************** End of file ****************************/
