/*
 * File:		mcf52223_sysinit.c
 * Purpose:		Power-on Reset configuration of the MCF52223.
 *
 * Notes: 
 *
 */
#include "support_common.h"
#include "exceptions.h"


/********************************************************************/
static void scm_init(void)
{
	/*
	 * Enable on-chip modules to access internal SRAM
	 */
	MCF_SCM_RAMBAR = (0
		| MCF_SCM_RAMBAR_BA(RAMBAR_ADDRESS)
		| MCF_SCM_RAMBAR_BDE);
}

/********************************************************************/

/*
 * Out of reset, the low-level assembly code calls this routine to
 * initialize the mcf5206e for this board. A temporary stack has been
 * setup in the internal SRAM, and the stack pointer will be changed
 * to point to DRAM once this routine returns.
 */
void __initialize_hardware(void)
{
	/*******************************************************
	*	Out of reset, the low-level assembly code calls this 
	*	routine to initialize the MCF52223 modules for the  
	*	M522223EVB board. 
	********************************************************/


	asm 
	{
	    /* Initialize IPSBAR */
	    move.l  #__IPSBAR,d0
	       andi.l  #0xC0000000,d0 // need to mask
	    add.l   #0x1,d0
	    move.l  d0,0x40000000

	    

	    /* Initialize FLASHBAR */
	    move.l  #__FLASHBAR,d0
	       andi.l  #0xFFF80000,d0 // need to mask
	    add.l   #0x61,d0
	    movec   d0,FLASHBAR

	}

   
	/* Enable debug */
	MCF_GPIO_PDDPAR = 0x0F;
	
	/* Set real time clock freq */
	MCF_CLOCK_RTCDR = 48000000;
	
	scm_init();	

	initialize_exceptions();
}



